==> qcad-3.15.5.3.tgz: lib/qcad/scripts/Widgets/StatusBar/ts/StatusBar_de.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="de_DE">
<context>
    <name>StatusBar</name>
    <message>
        <location filename="../PreferencesPage.ui" line="+47"/>
        <source>Status Bar Font:</source>
        <translation>Schrift der Statusleiste:</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Status Bar Widgets</source>
        <translation>Statuszeilenwidgets</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Coordinate display</source>
        <translation>Koordinatenanzeige</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Mouse display</source>
        <translation>Mausanzeige</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Selection display</source>
        <translation>Selektionsanzeige</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Progress display</source>
        <translation>Fortschrittsanzeige</translation>
    </message>
    <message>
        <location filename="../StatusBar.js" line="+32"/>
        <source>Widgets</source>
        <translation>Widgets</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Status Bar</source>
        <translation>Statuszeile</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>&amp;Status Bar</source>
        <translation>&amp;Statuszeile</translation>
    </message>
</context>
</TS>

==> qcad-3.21.2.3.tgz: lib/qcad/scripts/Widgets/StatusBar/ts/StatusBar_de.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="de_DE">
<context>
    <name>StatusBar</name>
    <message>
        <location filename="../PreferencesPage.ui" line="+53"/>
        <source>Status Bar Font:</source>
        <translation>Schrift der Statusleiste:</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Status Bar Widgets</source>
        <translation>Statuszeilenwidgets</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Coordinate display</source>
        <translation>Koordinatenanzeige</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Mouse display</source>
        <translation>Mausanzeige</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Selection display</source>
        <translation>Selektionsanzeige</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Progress display</source>
        <translation>Fortschrittsanzeige</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Show status tips</source>
        <translation>Statustips anzeigen</translation>
    </message>
    <message>
        <source>Show status tips in status bar </source>
        <translation type="obsolete">Status tips anzeigen in der Statusleiste</translation>
    </message>
    <message>
        <location filename="../StatusBar.js" line="+32"/>
        <source>Widgets</source>
        <translation>Widgets</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Status Bar</source>
        <translation>Statuszeile</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>&amp;Status Bar</source>
        <translation>&amp;Statuszeile</translation>
    </message>
</context>
</TS>
